@@ -8,4 +8,8 @@
 """
 
 KEY_OUTPUT = 'output'
-KEY_LOSS = 'loss'
\ No newline at end of file
+KEY_LOSS = 'loss'
+
+KEY_IMGS = 'imgs'
+KEY_TARGETS = 'targets'
+KEY_CLASSES = 'classes'
